uhammer package
===============

All listed classes and functions are available by importing
from `uhammer`.

uhammer.lnprob\_adapters module
-------------------------------

.. automodule:: uhammer.lnprob_adapters
    :members:
    :undoc-members:
    :show-inheritance:

uhammer.parameters module
-------------------------

.. automodule:: uhammer.parameters
    :members:
    :undoc-members:
    :show-inheritance:

uhammer.persisting module
-------------------------

.. automodule:: uhammer.persisting
    :members:
    :undoc-members:
    :show-inheritance:

uhammer.sampler module
----------------------

.. automodule:: uhammer.sampler
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: uhammer
    :members:
    :undoc-members:
    :show-inheritance:
